This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

fix comment in rs6000/host-darwin.c


Self-explanatory.  Bootstrapped on powerpc-darwin.

-- 
- Geoffrey Keating <geoffk@apple.com>

===File ~/patches/gcc-darwinoverflowcomment.patch===========
2003-02-11  Geoffrey Keating  <geoffk@apple.com>

	* config/rs6000/host-darwin.c: Fix comment.

Index: config/rs6000/host-darwin.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/config/rs6000/host-darwin.c,v
retrieving revision 1.1
diff -u -p -u -p -r1.1 host-darwin.c
--- config/rs6000/host-darwin.c	6 Feb 2003 01:47:56 -0000	1.1
+++ config/rs6000/host-darwin.c	11 Feb 2003 20:37:29 -0000
@@ -38,11 +38,11 @@ extern int sigaltstack(const stack_t *, 
 #undef HOST_HOOKS_EXTRA_SIGNALS
 #define HOST_HOOKS_EXTRA_SIGNALS darwin_rs6000_extra_signals
 
-/* On Darwin/powerpc, a stack fault can be detected as a SIGSEGV that
-   faulted on an instruction that's either
-   or
-   stwux %r1,xxx,%r1
-*/
+/* On Darwin/powerpc, hitting the stack limit turns into a SIGSEGV.
+   This code detects the difference between hitting the stack limit and
+   a true wild pointer dereference by looking at the instruction that
+   faulted; only a few kinds of instruction are used to access below
+   the previous bottom of the stack.  */
 
 static void
 segv_crash_handler (sig)
============================================================


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]